==> OpenID-1.0.0.tar.gz: OpenID/function.admin_tab_providers.php <==
<?php

/*
 *      Copyright 2010 Henrik Lennartsson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */


/* @var $this OpenID */
/* @var $gCms CmsObject */

function CreateProviderInput($provider, $module) {
    global $smarty;
    $smarty->assign('input_'.$provider,
		RRUtils::myCreateInputCheckbox($id, 'input_provider_'.$provider, 1,
					       $module->GetPreference('enable_provider_'.$provider,1)));
}

$smarty->assign('startform',
		$this->CreateFormStart( $id, 'admin_updateproviders'));
$smarty->assign('endform', $this->CreateFormEnd());

CreateProviderInput('google', $this);
CreateProviderInput('yahoo', $this);
CreateProviderInput('aol', $this);
CreateProviderInput('myopenid', $this);
CreateProviderInput('myspace', $this);
CreateProviderInput('flickr', $this);
CreateProviderInput('facebook', $this);
CreateProviderInput('technorati', $this);
CreateProviderInput('wordpress', $this);
CreateProviderInput('blogger', $this);
CreateProviderInput('livejournal', $this);
CreateProviderInput('claimid', $this);
CreateProviderInput('vidoop', $this);
CreateProviderInput('verisign', $this);

$smarty->assign('submit',
		$this->CreateInputSubmit ($id, 'submit',
					  $this->Lang('submit'),'',''));
$smarty->assign ('cancel',
		 $this->CreateInputSubmit ($id, 'cancel',
					   $this->Lang('cancel')));

echo $this->ProcessTemplate('admin_tab_providers.tpl');
?>

==> OpenID-1.2.1.tar.gz: OpenID/function.admin_tab_providers.php <==
<?php

/*
 *      Copyright 2010 Henrik Lennartsson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */


/* @var $this OpenID */
/* @var $gCms CmsObject */

function CreateProviderInput($provider, $module, $default = 1) {
    global $smarty;
    $smarty->assign('input_'.$provider,
		RRUtils::myCreateInputCheckbox($id, 'input_provider_'.$provider, 1,
					       $module->GetPreference('enable_provider_'.$provider,$default)));
}

$smarty->assign('startform',
		$this->CreateFormStart( $id, 'admin_updateproviders'));
$smarty->assign('endform', $this->CreateFormEnd());

CreateProviderInput('google', $this);
CreateProviderInput('yahoo', $this);
CreateProviderInput('aol', $this);
CreateProviderInput('myopenid', $this);
CreateProviderInput('myspace', $this);
CreateProviderInput('flickr', $this);
CreateProviderInput('facebook', $this, 0);
CreateProviderInput('twitter', $this, 0);
CreateProviderInput('twitter_small', $this, 0);
CreateProviderInput('technorati', $this);
CreateProviderInput('wordpress', $this);
CreateProviderInput('blogger', $this);
CreateProviderInput('livejournal', $this);
CreateProviderInput('claimid', $this);
CreateProviderInput('vidoop', $this);
CreateProviderInput('verisign', $this);

$smarty->assign('submit',
		$this->CreateInputSubmit ($id, 'submit',
					  $this->Lang('submit'),'',''));
$smarty->assign ('cancel',
		 $this->CreateInputSubmit ($id, 'cancel',
					   $this->Lang('cancel')));

echo $this->ProcessTemplate('admin_tab_providers.tpl');
?>
